---
title: Solitude
id: solitude
layout: default.haml
author: Henry David Thoreau
date: 2018-04-15
chapter: 5
kind: article
---

## Solitude

This is a delicious evening, when the whole body is one sense, and
imbibes delight through every pore. I go and come with a strange
liberty in Nature, a part of herself. As I walk along the stony shore
of the pond in my shirt sleeves, though it is cool as well as cloudy
and windy, and I see nothing special to attract me, all the elements
are unusually congenial to me. The bullfrogs trump to usher in the
night, and the note of the whippoorwill is borne on the rippling wind
from over the water. Sympathy with the fluttering alder and poplar
leaves almost takes away my breath; yet, like the lake, my serenity is
rippled but not ruffled. These small waves raised by the evening wind
are as remote from storm as the smooth reflecting surface. Though it is
now dark, the wind still blows and roars in the wood, the waves still
dash, and some creatures lull the rest with their notes. The repose is
never complete. The wildest animals do not repose, but seek their prey
now; the fox, and skunk, and rabbit, now roam the fields and woods
without fear. They are Nature’s watchmen,—links which connect the days
of animated life.

When I return to my house I find that visitors have been there and left
their cards, either a bunch of flowers, or a wreath of evergreen, or a
name in pencil on a yellow walnut leaf or a chip. They who come rarely
to the woods take some little piece of the forest into their hands to
play with by the way, which they leave, either intentionally or
accidentally. One has peeled a willow wand, woven it into a ring, and
dropped it on my table. I could always tell if visitors had called in
my absence, either by the bended twigs or grass, or the print of their
shoes, and generally of what sex or age or quality they were by some
slight trace left, as a flower dropped, or a bunch of grass plucked and
thrown away, even as far off as the railroad, half a mile distant, or
by the lingering odor of a cigar or pipe. Nay, I was frequently
notified of the passage of a traveller along the highway sixty rods off
by the scent of his pipe.

There is commonly sufficient space about us. Our horizon is never quite
at our elbows. The thick wood is not just at our door, nor the pond,
but somewhat is always clearing, familiar and worn by us, appropriated
and fenced in some way, and reclaimed from Nature. For what reason have
I this vast range and circuit, some square miles of unfrequented
forest, for my privacy, abandoned to me by men? My nearest neighbor is
a mile distant, and no house is visible from any place but the
hill-tops within half a mile of my own. I have my horizon bounded by
woods all to myself; a distant view of the railroad where it touches
the pond on the one hand, and of the fence which skirts the woodland
road on the other. But for the most part it is as solitary where I live
as on the prairies. It is as much Asia or Africa as New England. I
have, as it were, my own sun and moon and stars, and a little world all
to myself. At night there was never a traveller passed my house, or
knocked at my door, more than if I were the first or last man; unless
it were in the spring, when at long intervals some came from the
village to fish for pouts,—they plainly fished much more in the Walden
Pond of their own natures, and baited their hooks with darkness,—but
they soon retreated, usually with light baskets, and left “the world to
darkness and to me,” and the black kernel of the night was never
profaned by any human neighborhood. I believe that men are generally
still a little afraid of the dark, though the witches are all hung, and
Christianity and candles have been introduced.

Yet I experienced sometimes that the most sweet and tender, the most
innocent and encouraging society may be found in any natural object,
even for the poor misanthrope and most melancholy man. There can be no
very black melancholy to him who lives in the midst of Nature and has
his senses still. There was never yet such a storm but it was Æolian
music to a healthy and innocent ear. Nothing can rightly compel a
simple and brave man to a vulgar sadness. While I enjoy the friendship
of the seasons I trust that nothing can make life a burden to me. The
gentle rain which waters my beans and keeps me in the house to-day is
not drear and melancholy, but good for me too. Though it prevents my
hoeing them, it is of far more worth than my hoeing. If it should
continue so long as to cause the seeds to rot in the ground and destroy
the potatoes in the low lands, it would still be good for the grass on
the uplands, and, being good for the grass, it would be good for me.
Sometimes, when I compare myself with other men, it seems as if I were
more favored by the gods than they, beyond any deserts that I am
conscious of; as if I had a warrant and surety at their hands which my
fellows have not, and were especially guided and guarded. I do not
flatter myself, but if it be possible they flatter me. I have never
felt lonesome, or in the least oppressed by a sense of solitude, but
once, and that was a few weeks after I came to the woods, when, for an
hour, I doubted if the near neighborhood of man was not essential to a
serene and healthy life. To be alone was something unpleasant. But I
was at the same time conscious of a slight insanity in my mood, and
seemed to foresee my recovery. In the midst of a gentle rain while
these thoughts prevailed, I was suddenly sensible of such sweet and
beneficent society in Nature, in the very pattering of the drops, and
in every sound and sight around my house, an infinite and unaccountable
friendliness all at once like an atmosphere sustaining me, as made the
fancied advantages of human neighborhood insignificant, and I have
never thought of them since. Every little pine needle expanded and
swelled with sympathy and befriended me. I was so distinctly made aware
of the presence of something kindred to me, even in scenes which we are
accustomed to call wild and dreary, and also that the nearest of blood
to me and humanest was not a person nor a villager, that I thought no
place could ever be strange to me again.—

     “Mourning untimely consumes the sad;
     Few are their days in the land of the living,
     Beautiful daughter of Toscar.”

Some of my pleasantest hours were during the long rain storms in the
spring or fall, which confined me to the house for the afternoon as
well as the forenoon, soothed by their ceaseless roar and pelting; when
an early twilight ushered in a long evening in which many thoughts had
time to take root and unfold themselves. In those driving north-east
rains which tried the village houses so, when the maids stood ready
with mop and pail in front entries to keep the deluge out, I sat behind
my door in my little house, which was all entry, and thoroughly enjoyed
its protection. In one heavy thunder shower the lightning struck a
large pitch-pine across the pond, making a very conspicuous and
perfectly regular spiral groove from top to bottom, an inch or more
deep, and four or five inches wide, as you would groove a
walking-stick. I passed it again the other day, and was struck with awe
on looking up and beholding that mark, now more distinct than ever,
where a terrific and resistless bolt came down out of the harmless sky
eight years ago. Men frequently say to me, “I should think you would
feel lonesome down there, and want to be nearer to folks, rainy and
snowy days and nights especially.” I am tempted to reply to such,—This
whole earth which we inhabit is but a point in space. How far apart,
think you, dwell the two most distant inhabitants of yonder star, the
breadth of whose disk cannot be appreciated by our instruments? Why
should I feel lonely? is not our planet in the Milky Way? This which
you put seems to me not to be the most important question. What sort of
space is that which separates a man from his fellows and makes him
solitary? I have found that no exertion of the legs can bring two minds
much nearer to one another. What do we want most to dwell near to? Not
to many men surely, the depot, the post-office, the bar-room, the
meeting-house, the school-house, the grocery, Beacon Hill, or the Five
Points, where men most congregate, but to the perennial source of our
life, whence in all our experience we have found that to issue, as the
willow stands near the water and sends out its roots in that direction.
This will vary with different natures, but this is the place where a
wise man will dig his cellar.... I one evening overtook one of my
townsmen, who has accumulated what is called “a handsome
property,”—though I never got a _fair_ view of it,—on the Walden road,
driving a pair of cattle to market, who inquired of me how I could
bring my mind to give up so many of the comforts of life. I answered
that I was very sure I liked it passably well; I was not joking. And so
I went home to my bed, and left him to pick his way through the
darkness and the mud to Brighton,—or Bright-town,—which place he would
reach some time in the morning.

Any prospect of awakening or coming to life to a dead man makes
indifferent all times and places. The place where that may occur is
always the same, and indescribably pleasant to all our senses. For the
most part we allow only outlying and transient circumstances to make
our occasions. They are, in fact, the cause of our distraction. Nearest
to all things is that power which fashions their being. _Next_ to us
the grandest laws are continually being executed. _Next_ to us is not
the workman whom we have hired, with whom we love so well to talk, but
the workman whose work we are.

“How vast and profound is the influence of the subtile powers of Heaven
and of Earth!”

“We seek to perceive them, and we do not see them; we seek to hear
them, and we do not hear them; identified with the substance of things,
they cannot be separated from them.”

“They cause that in all the universe men purify and sanctify their
hearts, and clothe themselves in their holiday garments to offer
sacrifices and oblations to their ancestors. It is an ocean of subtile
intelligences. They are every where, above us, on our left, on our
right; they environ us on all sides.”

We are the subjects of an experiment which is not a little interesting
to me. Can we not do without the society of our gossips a little while
under these circumstances,—have our own thoughts to cheer us? Confucius
says truly, “Virtue does not remain as an abandoned orphan; it must of
necessity have neighbors.”

With thinking we may be beside ourselves in a sane sense. By a
conscious effort of the mind we can stand aloof from actions and their
consequences; and all things, good and bad, go by us like a torrent. We
are not wholly involved in Nature. I may be either the drift-wood in
the stream, or Indra in the sky looking down on it. I _may_ be affected
by a theatrical exhibition; on the other hand, I _may not_ be affected
by an actual event which appears to concern me much more. I only know
myself as a human entity; the scene, so to speak, of thoughts and
affections; and am sensible of a certain doubleness by which I can
stand as remote from myself as from another. However intense my
experience, I am conscious of the presence and criticism of a part of
me, which, as it were, is not a part of me, but spectator, sharing no
experience, but taking note of it; and that is no more I than it is
you. When the play, it may be the tragedy, of life is over, the
spectator goes his way. It was a kind of fiction, a work of the
imagination only, so far as he was concerned. This doubleness may
easily make us poor neighbors and friends sometimes.

I find it wholesome to be alone the greater part of the time. To be in
company, even with the best, is soon wearisome and dissipating. I love
to be alone. I never found the companion that was so companionable as
solitude. We are for the most part more lonely when we go abroad among
men than when we stay in our chambers. A man thinking or working is
always alone, let him be where he will. Solitude is not measured by the
miles of space that intervene between a man and his fellows. The really
diligent student in one of the crowded hives of Cambridge College is as
solitary as a dervish in the desert. The farmer can work alone in the
field or the woods all day, hoeing or chopping, and not feel lonesome,
because he is employed; but when he comes home at night he cannot sit
down in a room alone, at the mercy of his thoughts, but must be where
he can “see the folks,” and recreate, and as he thinks remunerate
himself for his day’s solitude; and hence he wonders how the student
can sit alone in the house all night and most of the day without ennui
and “the blues;” but he does not realize that the student, though in
the house, is still at work in _his_ field, and chopping in _his_
woods, as the farmer in his, and in turn seeks the same recreation and
society that the latter does, though it may be a more condensed form of
it.

Society is commonly too cheap. We meet at very short intervals, not
having had time to acquire any new value for each other. We meet at
meals three times a day, and give each other a new taste of that old
musty cheese that we are. We have had to agree on a certain set of
rules, called etiquette and politeness, to make this frequent meeting
tolerable and that we need not come to open war. We meet at the
post-office, and at the sociable, and about the fireside every night;
we live thick and are in each other’s way, and stumble over one
another, and I think that we thus lose some respect for one another.
Certainly less frequency would suffice for all important and hearty
communications. Consider the girls in a factory,—never alone, hardly in
their dreams. It would be better if there were but one inhabitant to a
square mile, as where I live. The value of a man is not in his skin,
that we should touch him.

I have heard of a man lost in the woods and dying of famine and
exhaustion at the foot of a tree, whose loneliness was relieved by the
grotesque visions with which, owing to bodily weakness, his diseased
imagination surrounded him, and which he believed to be real. So also,
owing to bodily and mental health and strength, we may be continually
cheered by a like but more normal and natural society, and come to know
that we are never alone.

I have a great deal of company in my house; especially in the morning,
when nobody calls. Let me suggest a few comparisons, that some one may
convey an idea of my situation. I am no more lonely than the loon in
the pond that laughs so loud, or than Walden Pond itself. What company
has that lonely lake, I pray? And yet it has not the blue devils, but
the blue angels in it, in the azure tint of its waters. The sun is
alone, except in thick weather, when there sometimes appear to be two,
but one is a mock sun. God is alone,—but the devil, he is far from
being alone; he sees a great deal of company; he is legion. I am no
more lonely than a single mullein or dandelion in a pasture, or a bean
leaf, or sorrel, or a horse-fly, or a bumble-bee. I am no more lonely
than the Mill Brook, or a weathercock, or the north star, or the south
wind, or an April shower, or a January thaw, or the first spider in a
new house.

I have occasional visits in the long winter evenings, when the snow
falls fast and the wind howls in the wood, from an old settler and
original proprietor, who is reported to have dug Walden Pond, and
stoned it, and fringed it with pine woods; who tells me stories of old
time and of new eternity; and between us we manage to pass a cheerful
evening with social mirth and pleasant views of things, even without
apples or cider,—a most wise and humorous friend, whom I love much, who
keeps himself more secret than ever did Goffe or Whalley; and though he
is thought to be dead, none can show where he is buried. An elderly
dame, too, dwells in my neighborhood, invisible to most persons, in
whose odorous herb garden I love to stroll sometimes, gathering simples
and listening to her fables; for she has a genius of unequalled
fertility, and her memory runs back farther than mythology, and she can
tell me the original of every fable, and on what fact every one is
founded, for the incidents occurred when she was young. A ruddy and
lusty old dame, who delights in all weathers and seasons, and is likely
to outlive all her children yet.

The indescribable innocence and beneficence of Nature,—of sun and wind
and rain, of summer and winter,—such health, such cheer, they afford
forever! and such sympathy have they ever with our race, that all
Nature would be affected, and the sun’s brightness fade, and the winds
would sigh humanely, and the clouds rain tears, and the woods shed
their leaves and put on mourning in midsummer, if any man should ever
for a just cause grieve. Shall I not have intelligence with the earth?
Am I not partly leaves and vegetable mould myself?

What is the pill which will keep us well, serene, contented? Not my or
thy great-grandfather’s, but our great-grandmother Nature’s universal,
vegetable, botanic medicines, by which she has kept herself young
always, outlived so many old Parrs in her day, and fed her health with
their decaying fatness. For my panacea, instead of one of those quack
vials of a mixture dipped from Acheron and the Dead Sea, which come out
of those long shallow black-schooner looking wagons which we sometimes
see made to carry bottles, let me have a draught of undiluted morning
air. Morning air! If men will not drink of this at the fountain-head of
the day, why, then, we must even bottle up some and sell it in the
shops, for the benefit of those who have lost their subscription ticket
to morning time in this world. But remember, it will not keep quite
till noon-day even in the coolest cellar, but drive out the stopples
long ere that and follow westward the steps of Aurora. I am no
worshipper of Hygeia, who was the daughter of that old herb-doctor
Æsculapius, and who is represented on monuments holding a serpent in
one hand, and in the other a cup out of which the serpent sometimes
drinks; but rather of Hebe, cupbearer to Jupiter, who was the daughter
of Juno and wild lettuce, and who had the power of restoring gods and
men to the vigor of youth. She was probably the only thoroughly
sound-conditioned, healthy, and robust young lady that ever walked the
globe, and wherever she came it was spring.


